"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.filesChanged = exports.hash = void 0;
const path_1 = __importDefault(require("path"));
// included here in preference to goldstack utils-sh to avoid circular dependency
const console_1 = require("console");
const child_process_1 = require("child_process");
const command_exists_1 = __importDefault(require("command-exists"));
const isDebug = process.env.GOLDSTACK_DEBUG || process.env.DEBUG;
// included here to avoid circular dependency for log package
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const debug = (msg) => {
    if (isDebug) {
        console.log(msg);
    }
};
const exec = (cmd, params) => {
    const res = (0, child_process_1.execSync)(cmd);
    if (!(params === null || params === void 0 ? void 0 : params.silent)) {
        console.log(res.toString());
    }
    return res.toString();
};
const hash = () => {
    if (!(0, command_exists_1.default)('git')) {
        throw new Error('git is not installed or not available as command.');
    }
    const hash = exec('git rev-parse --short HEAD', { silent: true }).trim();
    return hash;
};
exports.hash = hash;
const filesChanged = () => {
    let headChanged = false;
    let fileChanged = false;
    try {
        exec('git diff "HEAD..HEAD^1" --quiet -- . ');
    }
    catch (e) {
        debug('Detected change against HEAD^1 in ' + path_1.default.resolve('.'));
        headChanged = true;
    }
    try {
        exec('git diff --quiet -- . ');
    }
    catch (e) {
        debug('Detected uncommited change in ' + path_1.default.resolve('.'));
        fileChanged = true;
    }
    if (headChanged || fileChanged) {
        return true;
    }
    else {
        return false;
    }
};
exports.filesChanged = filesChanged;
const run = (args) => {
    (0, console_1.assert)(args[3] === '--exec');
    const [, , , , ...execCommands] = args;
    const execCommand = execCommands.join(' ');
    if (args[2] === 'changed') {
        if ((0, exports.filesChanged)()) {
            try {
                const res = exec(execCommand);
                console.log(res);
            }
            catch (e) {
                console.error('Error when running "' + execCommand + '"');
                process.exit(1);
            }
        }
        else {
            console.log('No file changes detected in ' + path_1.default.resolve('.'));
        }
    }
    else {
        console.log('Please provide argument changed.');
        process.exit(1);
    }
};
exports.run = run;
//# sourceMappingURL=utilsGit.js.map